@@ -2,7 +2,7 @@ package Tapper::CLI::Testrun::Command::listhost;
 BEGIN {
   $Tapper::CLI::Testrun::Command::listhost::AUTHORITY = 'cpan:TAPPER';
 }
-$Tapper::CLI::Testrun::Command::listhost::VERSION = '4.1.5';
+$Tapper::CLI::Testrun::Command::listhost::VERSION = '4.1.6';
 use 5.010;
 
 use strict;
@@ -93,7 +93,7 @@ sub execute {
         my %options= (order_by => 'name');
         my %search;
         $search{active}     = 1 if $opt->{active};
-        $search{is_deleted} = {-in => [ 0, undef ] } unless $opt->{all};
+        $search{is_deleted} = [ 0, undef ] unless $opt->{all};
         $search{free}   = 1 if $opt->{free};
 
         # ignore all options if host is requested by name
